@@ -26,7 +26,7 @@ city_t cities[] =
     {"Denver", 39, 44, 104, 59, -7, DST_USOFA},
     {"Detroit", 42, 20, 83, 2, -5, DST_USOFA},
     {"Eilat", 29, 33, -34, -57, 2, DST_ISRAEL},
-    {"Gibraltar", 36, 0, 5, 0, -10, DST_USOFA},
+    {"Gibraltar", 36, 8, 5, 21, 1, DST_EU},
     {"Haifa", 32, 49, -34, -59, 2, DST_ISRAEL},
     {"Hawaii", 19, 30, 155, 30, -10, DST_NONE},
     {"Houston", 29, 46, 95, 22, -6, DST_USOFA},
@@ -39,11 +39,11 @@ city_t cities[] =
     {"Los Angeles", 34, 4, 118, 15, -8, DST_USOFA},
     {"Miami", 25, 46, 80, 12, -5, DST_USOFA},
     {"Melbourne", -37, -52, -145, -8, 10, DST_AUNZ},
-    {"Mexico City", 19, 24, 99, 9, -6, DST_USOFA},
+    {"Mexico City", 19, 24, 99, 9, -6, DST_MX},
     {"Montreal", 45, 30, 73, 36, -5, DST_USOFA},
     {"Moscow", 55, 45, -37, -42, 3, DST_EU},
     {"New York", 40, 43, 74, 1, -5, DST_USOFA},
-    {"Omaha", 41, 16, 95, 56, -7, DST_USOFA},
+    {"Omaha", 41, 16, 95, 56, -6, DST_USOFA},
     {"Ottawa", 45, 42, 75, 71, -5, DST_USOFA},
     {"Panama City", 8, 58, 79, 32, -5, DST_NONE},
     {"Paris", 48, 52, -2, -20, 1, DST_EU},
