@@ -5,7 +5,7 @@
 
    http://sourceforge.net/projects/hebcal
 
-   $Id: holidays.c,v 1.22 2006/09/08 05:30:53 sadinoff Exp $
+   $Id: holidays.c 169 2010-09-14 17:57:49Z mradwin $
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -260,6 +260,13 @@ holinput_t inp_holidays[] =
       NULL
    },
 
+   {
+      {IYYAR, 14, IGNORE_YEAR},
+      {"Pesach Sheni", NULL, "\364\361\347\351\345\355 \371\360\351"},
+      0,
+      NULL
+   },
+
    {
       {IYYAR, 18, IGNORE_YEAR},
       {"Lag B'Omer", NULL, "\354\"\342 \341\362\345\356\370"},
@@ -308,7 +315,7 @@ holinput_t inp_holidays[] =
 #define HOLIDAY_PURIM_KATAN     LANGUAGE2(var_hol_names[5].name)
 #define HOLIDAY_SHABBAT_HACHODESH       LANGUAGE2(var_hol_names[6].name)
 #define HOLIDAY_SHABBAT_HAGADOL LANGUAGE2(var_hol_names[7].name)
-#define HOLIDAY_SHABBAT_HAZON   LANGUAGE2(var_hol_names[8].name)
+#define HOLIDAY_SHABBAT_CHAZON   LANGUAGE2(var_hol_names[8].name)
 #define HOLIDAY_SHABBAT_NACHAMU LANGUAGE2(var_hol_names[9].name)
 #define HOLIDAY_SHABBAT_PARAH   LANGUAGE2(var_hol_names[10].name)
 #define HOLIDAY_SHABBAT_SHEKALIM        LANGUAGE2(var_hol_names[11].name)
@@ -324,6 +331,8 @@ holinput_t inp_holidays[] =
 #define HOLIDAY_YOM_HASHOAH     LANGUAGE2(var_hol_names[21].name)
 #define HOLIDAY_YOM_HAZIKARON   LANGUAGE2(var_hol_names[22].name)
 #define HOLIDAY_YOM_YERUSHALAYIM   LANGUAGE2(var_hol_names[23].name)
+#define HOLIDAY_EREV_PURIM   LANGUAGE2(var_hol_names[24].name)
+#define HOLIDAY_EREV_TISH_A_B_AV   LANGUAGE2(var_hol_names[25].name)
 
 struct variable_holiday_names {
    char *(name[3]);
@@ -336,7 +345,7 @@ struct variable_holiday_names {
   {{"Purim Katan", "Purim Koton", "\364\345\370\351\355 \367\350\357"}},
   {{"Shabbat HaChodesh", "Shabbos HaChodesh", "\371\341\372 \344\347\343\371"}},
   {{"Shabbat HaGadol", "Shabbos HaGadol", "\371\341\372 \344\342\343\345\354"}},
-  {{"Shabbat Hazon", "Shabbos Hazon", "\371\341\372 \344\346\345\357"}},
+  {{"Shabbat Chazon", "Shabbos Chazon", "\371\341\372 \347\346\345\357"}},
   {{"Shabbat Nachamu", "Shabbos Nachamu", "\371\341\372 \360\347\356\345"}},
   {{"Shabbat Parah", "Shabbos Parah", "\371\341\372 \364\370\344"}},
   {{"Shabbat Shekalim", "Shabbos Shekalim", "\371\341\372 \371\367\354\351\355"}},
@@ -352,6 +361,8 @@ struct variable_holiday_names {
   {{"Yom HaShoah", NULL, "\351\345\355 \344\371\345\340\344"}},
   {{"Yom HaZikaron", NULL, "\351\345\355 \344\346\353\370\345\357"}},
   {{"Yom Yerushalayim", NULL, "\351\345\355 \351\370\345\371\354\351\355"}},
+  {{"Erev Purim", NULL, "\362\370\341 \364\345\370\351\355"}},
+  {{"Erev Tish'a B'Av", NULL, "\362\370\341 \372\371\362\344 \341\340\341"}},
 };
 
 /*-------------------------------------------------------------------------*/
@@ -477,12 +488,20 @@ static void load_variable_holidays( int hYear )
         tmpholp->name = HOLIDAY_PURIM_KATAN;
         PushHoliday (tmpholp, &var_holidays[ADAR_I][14]);
         
+        tmpholp = getHolstorep ();
+        tmpholp->name = HOLIDAY_EREV_PURIM;
+        PushHoliday (tmpholp, &var_holidays[ADAR_II][13]);
+
         tmpholp = getHolstorep ();
         tmpholp->name = HOLIDAY_PURIM;
         PushHoliday (tmpholp, &var_holidays[ADAR_II][14]);
     }
     else
     {
+        tmpholp = getHolstorep ();
+        tmpholp->name = HOLIDAY_EREV_PURIM;
+        PushHoliday (tmpholp, &var_holidays[ADAR_I][13]);
+
         tmpholp = getHolstorep ();
         tmpholp->name = HOLIDAY_PURIM;
         PushHoliday (tmpholp, &var_holidays[ADAR_I][14]);
@@ -505,8 +524,8 @@ static void load_variable_holidays( int hYear )
     
     tmpholp = getHolstorep ();
     tmpholp->name = HOLIDAY_TA_ANIT_BECHOROT;
-    if ((passover - 1L) % 7L >= 5)
-    {                            /* saturday or sunday */
+    if ((passover - 1L) % 7L == SAT)
+    {   /* if the fast falls on Shabbat, move to Thursday */
         tempDt = abs2hebrew (day_on_or_before (THU, passover));
         PushHoliday (tmpholp, &var_holidays[tempDt.mm][tempDt.dd]);
     }
@@ -519,12 +538,15 @@ static void load_variable_holidays( int hYear )
     tempDt = abs2hebrew (day_on_or_before (SAT, passover - 1L));
     PushHoliday (tmpholp, &var_holidays[tempDt.mm][tempDt.dd]);
     
-    if (hYear > 5698)
-    {                            /* these only really make sense after 1938 */
+    if (hYear >= 5711)
+    {                            /* Yom HaShoah first observed in 1951 */
         tmpholp = getHolstorep ();
         tmpholp->name = HOLIDAY_YOM_HASHOAH;
         PushHoliday (tmpholp, &var_holidays[NISAN][27]);
-        
+    }
+
+    if (hYear > 5708)
+    {                            /* only really makes sense after 1948 */
         tmpholp = getHolstorep ();
         tmpholp->name = HOLIDAY_YOM_HAZIKARON;
         if (passover % 7L == SUN)
@@ -538,23 +560,9 @@ static void load_variable_holidays( int hYear )
         else 
             tempDt.dd = 5;
         PushHoliday (tmpholp, &var_holidays[IYYAR][tempDt.dd - 1]);
-    }
 
-    if (hYear > 5708)
-    {                            /* only really makes sense after 1948 */
         tmpholp = getHolstorep ();
         tmpholp->name = HOLIDAY_YOM_HAATZMA_UT;
-        if (passover % 7L == SUN)
-            tempDt.dd = 3;
-        else if (passover % 7L == SAT)
-            tempDt.dd = 4;
-        else if( hYear < 5764 )
-            tempDt.dd = 5;
-        else if( passover % 7L == TUE ) /* no Yom Hazikaron on motzei shabbat allowed after 5764*/
-            tempDt.dd = 6;
-        else 
-            tempDt.dd = 5;
-
         PushHoliday (tmpholp, &var_holidays[IYYAR][tempDt.dd]);
     }
 
@@ -574,10 +582,15 @@ static void load_variable_holidays( int hYear )
     PushHoliday (tmpholp, &var_holidays[tempDt.mm][tempDt.dd]);
     
     tmpholp = getHolstorep ();
-    tmpholp->name = HOLIDAY_SHABBAT_HAZON;
+    tmpholp->name = HOLIDAY_SHABBAT_CHAZON;
     tempDt = abs2hebrew (day_on_or_before (SAT, tishaBav));
     PushHoliday (tmpholp, &var_holidays[tempDt.mm][tempDt.dd]);
     
+    tmpholp = getHolstorep ();
+    tmpholp->name = HOLIDAY_EREV_TISH_A_B_AV;
+    PushHoliday (tmpholp, &var_holidays[AV]
+                 [tishaBav % 7L == SAT ? 9 : 8]);
+    
     tmpholp = getHolstorep ();
     tmpholp->name = HOLIDAY_TISH_A_B_AV;
     PushHoliday (tmpholp, &var_holidays[AV]
@@ -590,11 +603,8 @@ static void load_variable_holidays( int hYear )
     
     tmpholp = getHolstorep ();
     tmpholp->name = HOLIDAY_ASARA_B_TEVET;
-    if (tevet10 % 7L >= 5)
-    {                            /* saturday or sunday */
-        tempDt = abs2hebrew (day_on_or_before (THU, tevet10));
-        PushHoliday (tmpholp, &var_holidays[tempDt.mm][tempDt.dd]);
-    }
+    if (tevet10 % 7L == SAT)
+        PushHoliday (tmpholp, &var_holidays[TEVET][11]);
     else
         PushHoliday (tmpholp, &var_holidays[TEVET][10]);
     
@@ -765,6 +775,17 @@ void init_yahrtzeits( int hyear )
         }
         /* In all other cases, use the normal anniversary of the date of death. */
 
+        /* advance day to rosh chodesh if needed */
+        if (hDeath.mm == CHESHVAN && hDeath.dd == 30
+            && !long_cheshvan(hyear)) {
+            hDeath.mm = KISLEV;
+            hDeath.dd = 1;
+        } else if (hDeath.mm == KISLEV && hDeath.dd == 30
+                   && short_kislev(hyear)) {
+            hDeath.mm = TEVET;
+            hDeath.dd = 1;
+        }
+
         eventStr = s + index + 1; /* get the name of the event */
         /*    if (eventStr[strlen(eventStr)-1] == '\n') */
         eventStr[strlen (eventStr) - 1] = '\0';   /* chop off the \n */
