@@ -130,8 +130,8 @@ static char
    "Note: Use COMPLETE Years.  You probably aren't interested in ",
    "hebcal 93, but rather hebcal 1993.",
    "", "",
-   "Hebcal is copyright (c) 1994-2004 By Danny Sadinoff",
-   "Portions Copyright (c) 2002 Michael J. Radwin. All rights reserved.",
+   "Hebcal is copyright (c) 1994-2011 By Danny Sadinoff",
+   "Portions Copyright (c) 2011 Michael J. Radwin. All rights reserved.",
    "",
    "This program is free software; you can redistribute it and/or",
    "modify it under the terms of the GNU General Public License",
@@ -165,6 +165,7 @@ dst_t savings_bank[] =
     {"israel", DST_ISRAEL},
     {"eu", DST_EU},
     {"aunz", DST_AUNZ},
+    {"mx", DST_MX},
     {"", 0}
 };
 
@@ -225,13 +226,26 @@ void print_city_data( void )
          cities[cnum].name;
          cnum++)
     {
-        printf("%s (%dd%d' %c lat, %dd%d' %c long, GMT %s%d:00)\n",
+	dst_t *pdst;
+	const char *dst_name = NULL;
+
+	for (pdst = savings_bank; pdst->name != NULL; pdst++)
+	{
+	    if (cities[cnum].DST_scheme == pdst->DST_scheme)
+	    {
+		dst_name = pdst->name;
+		break;
+	    }
+	}
+
+        printf("%s (%dd%d' %c lat, %dd%d' %c long, GMT %s%d:00, %s)\n",
               cities[cnum].name,
                abs(cities[cnum].latdeg), abs(cities[cnum].latmin),
                cities[cnum].latdeg < 0 ? 'S' : 'N',
                abs(cities[cnum].longdeg), abs(cities[cnum].longmin),
                cities[cnum].longdeg > 0 ? 'W' : 'E',
-               cities[cnum].TZ < 0 ? "" : "+", cities[cnum].TZ
+               cities[cnum].TZ < 0 ? "" : "+", cities[cnum].TZ,
+               dst_name ? dst_name : "unknown"
             );
     }
 }
@@ -718,6 +732,10 @@ int main(int argc, char* argv[])
             tempDate.mm = TISHREI;
             tempDate.yy = theYear;
             startAbs = hebrew2abs(tempDate);
+	    /* start yearly calendar with the day before RH (i.e. Erev
+	     * Rosh Hashanah)
+	     */
+	    startAbs--;
 
             tempDate.yy++;
             endAbs = hebrew2abs(tempDate) - 1;
